@@ -10,24 +10,18 @@
 #endif // _MSC_VER >= 1000
 
 #include <wchar.h>
-#include <datrie/trie.h>
 #include "worddef.h"
+#include "dict.h"
 
 class AbsWordSeg
 {
 public:
-  AbsWordSeg ();
   virtual ~AbsWordSeg ();
 
-  bool InitDict (const char* dictPath);
-  int WordSeg (const wchar_t* senstr, short int* outSeps, int outSepsSz);
+  int WordSeg (const Dict* dict, const wchar_t* senstr,
+               short int* outSeps, int outSepsSz);
 
 protected:
-  //============Function for Wordseg=====================
-  void SwapLinkSep ();
-  int GetBestSen (int bestidx, short int* outSeps, int outSepsSz);
-  void CreateWordList (void);
-  virtual int CreateSentence () = 0;    //return idx of best sen
   unsigned short int copySepData (short int sourceIdxSen,
                                   short int targetIdxSen,
                                   short int sepPoint);
@@ -40,16 +34,17 @@ protected:
   short int IdxSep[MAXLEN];
 
 private:
-  void InitData ();
+  //============Functions for Wordseg====================
+  void CreateWordList (const Dict* dict);
+  virtual int CreateSentence () = 0;    //return idx of best sen
+  int GetBestSen (int bestidx, short int* outSeps, int outSepsSz);
 
   //============Check Character Type Function============
   static bool IsLeadChar (wchar_t wc);
   static bool IsLastChar (wchar_t wc);
-  //============Check Karan rule=========================
-  static bool Has_Karun (const wchar_t* sen_ptr);
 
-private:
-    Trie*  MyDict;
+  //============Check Karan rule=========================
+  static bool HasKaran (const wchar_t* sen_ptr);
 };
 
 #endif
