@@ -16,10 +16,10 @@ class FilterX
 {
 public:
   FilterX (FILE* filein, FILE* fileout, bool isUniIn, bool isUniOut,
-           const char* wordBreakStr);
+           const wchar_t* wordBreakStr);
   virtual ~FilterX ();
 
-  const char* GetWordBreak ();
+  const wchar_t* GetWordBreak ();
 
   virtual bool GetNextToken (wchar_t* token, int tokenSz, bool* thaiFlag) = 0;
   virtual void Print (const wchar_t* token, bool thaiFlag) = 0;
@@ -31,12 +31,12 @@ protected:
   bool  isUniOut;
 
 private:
-  const char* wordBreakStr;
+  const wchar_t* wordBreakStr;
 };
 
 inline
 FilterX::FilterX (FILE* filein, FILE* fileout, bool isUniIn, bool isUniOut,
-                  const char* wordBreakStr)
+                  const wchar_t* wordBreakStr)
   : fpin (filein ? filein : stdin),
     fpout (fileout ? fileout : stdout),
     isUniIn (isUniIn),
@@ -51,7 +51,7 @@ FilterX::~FilterX ()
   fflush (fpout);
 }
 
-inline const char*
+inline const wchar_t*
 FilterX::GetWordBreak ()
 {
   return wordBreakStr;
